==> enterprisemodules-easy_type-2.49.0.tar.gz: enterprisemodules-easy_type-2.49.0/lib/puppet/type/validation.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'

Puppet::Type.newtype(:validation) do
  include EasyType

  desc <<-DESC
  This type allows you to validate settings on your system. Here is an example on how you can
  use this:

      validation { "Validate root user is uid 0":
        check           => '/usr/bin/grep -e "^root" /etc/passwd',
        expected_output => /root:x:0:0:root:\/root:\/bin\/bash/,
        report_as       => 'command',
        fail_message    => "User root not defined with uid 1 valdation output is: '%<output>s'",
        fail_command    => "/bin/send_to_montoring --node ${::fqdn} %<output>s",
      }

  This Puppet code executes the check `/bin/grep...` on your system and validates that the output equals the
  regular expression `/root..../`. If it passes, Puppet does nothing. Because `report_as` is set to `command`, 
  when the check fails, Puppet will execute the `fail_command` and pass in the `fail_message` text.
  DESC

  to_get_raw_resources do
    []
  end


  #
  # Register the result(s) of a control in the class. The puppet type validation_report can
  # then pass it to the puppet server or any oher place.
  #
  def self.register_result(qualified_control, result, message, failed_resources = [])
    return if qualified_control.nil?
    control, target = qualified_control.split(/\[|\]/)
    @results ||= {}
    #
    # SOmetimes insync is called multiple times. To guard aganst double messages, check if the message is already registered.
    #
    return if @results[qualified_control] && @results[qualified_control]['results'].any? {|e| e[:message] == message }

    @results[qualified_control] ||= {}
    @results[qualified_control]['control'] ||= control
    @results[qualified_control]['target'] ||= target
    @results[qualified_control]['results'] ||= []
    @results[qualified_control]['results'] << { message: message, result: result, failed_resources: failed_resources}
  end

  def self.results
    @results
  end

  on_modify do
    provider.report
  end

  def refresh
    output = provider.execute_check

    provider.report if !output.match?(resource[:expected_output])
  end

  parameter :name
  property  :check
  parameter :refreshonly
  parameter :environment
  parameter :timeout
  parameter :user
  parameter :group
  parameter :umask
  parameter :path
  parameter :cwd
  parameter :logoutput
  parameter :control
  parameter :skip
  parameter :failed_resources

  parameter :report_as
  parameter :expected_output
  parameter :not_allowed_output
  parameter :expected_value
  parameter :parse_value
  parameter :fail_message
  parameter :fail_command
end

==> enterprisemodules-easy_type-2.50.1.tar.gz: enterprisemodules-easy_type-2.50.1/lib/puppet/type/validation.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'

Puppet::Type.newtype(:validation) do
  include EasyType

  desc <<-DESC
  This type allows you to validate settings on your system. Here is an example on how you can
  use this:

      validation { "Validate root user is uid 0":
        check           => '/usr/bin/grep -e "^root" /etc/passwd',
        expected_output => /root:x:0:0:root:\/root:\/bin\/bash/,
        report_as       => 'command',
        fail_message    => "User root not defined with uid 1 valdation output is: '%<output>s'",
        fail_command    => "/bin/send_to_montoring --node ${::fqdn} %<output>s",
      }

  This Puppet code executes the check `/bin/grep...` on your system and validates that the output equals the
  regular expression `/root..../`. If it passes, Puppet does nothing. Because `report_as` is set to `command`, 
  when the check fails, Puppet will execute the `fail_command` and pass in the `fail_message` text.
  DESC

  to_get_raw_resources do
    []
  end


  #
  # Register the result(s) of a control in the class. The puppet type validation_report can
  # then pass it to the puppet server or any oher place.
  #
  def self.register_result(qualified_control, result, message, output = '')
    return if qualified_control.nil?
    control, target = qualified_control.split(/\[|\]/)
    @results ||= {}
    #
    # SOmetimes insync is called multiple times. To guard aganst double messages, check if the message is already registered.
    #
    return if @results[qualified_control] && @results[qualified_control]['results'].any? {|e| e[:message] == message }

    @results[qualified_control] ||= {}
    @results[qualified_control]['control'] ||= control
    @results[qualified_control]['target'] ||= target
    @results[qualified_control]['results'] ||= []
    @results[qualified_control]['results'] << { message: message, result: result, output: output}
  end

  def self.results
    @results
  end

  on_modify do
    provider.report
  end

  def refresh
    output = provider.execute_check

    provider.report if !output.match?(resource[:expected_output])
  end

  parameter :name
  property  :check
  parameter :refreshonly
  parameter :environment
  parameter :timeout
  parameter :user
  parameter :group
  parameter :umask
  parameter :path
  parameter :cwd
  parameter :logoutput
  parameter :control
  parameter :skip
  parameter :output

  parameter :report_as
  parameter :expected_output
  parameter :not_allowed_output
  parameter :expected_value
  parameter :parse_value
  parameter :fail_message
  parameter :fail_command
end
